@@ -30,10 +30,132 @@
 #include <pds/pdsmath.h>
 
 
+
+/** \fn int pds_symetric_ber_bsc_model(double rho,unsigned int M, double *BER)
+ *  \brief Retorna la taza de erro de bit, \f$BER\f$, 
+ *  en el problema CEO binario simétrico
+ *  de M fontes \f$ U_m, \forall ~ m \in \{1, 2, ..., M\}\f$, donde \f$\hat{U}_0\f$
+ *  representa la mejor aproximación de \f$U_0\f$ conociendo \f$U_1 U_2 ... U_M\f$. 
+ *
+ *  Estas fuentes son generadas pasando una fuente \f$U_0\f$, con probabilidade
+ *  \f$P(U_0=1)=0.5\f$ , atraves de M canales BSC
+ *  con probabilidades de error \f$P(U_m \neq U0 | U0)=\rho\f$.
+ *
+ *  <center>
+ *  \image html msbscpack.png "Bloque de M fuentes binarias correlacionadas"
+ *  </center>
+ *
+ *
+ *  Quando M es impar :
+ *  \f[ BER= \sum_{j=(M+1)/2}^{M} {{M}\choose{j}} {\rho}^j (1-\rho)^{M-j} \f]
+ *
+ *  Quando M es par :
+ *  \f[ BER= \sum_{j=(M/2)+1}^{M} {{M}\choose{j}} {\rho}^j (1-\rho)^{M-j}+0.5 {{M}\choose{M/2}} {\rho}^{M/2} (1-\rho)^{M/2} \f]
+ *
+ *  <b>!!!!CUIDADO ACTUAL \f$BER=P(U_m\neq U_0 | \lfloor \frac{M+1}{2} \rfloor\leq m \leq M)\f$ !!!!!</b>
+ *
+ *  The formula for calculus of BER is in \cite BER1 and other simplification in \cite BER2 \cite jointsbceo .
+ *
+ *  \param[in] rho Es la probabilidad de error de los canales BSC. \f$ P(U_m \neq U_0| U_0)=\rho \f$.
+ *  \param[in] M Es el número de canales BSC.
+ *  \param[out] BER es la taza de error de bit.
+ *  \return TRUE si todo fue bien, o FALSE sino. 
+ *  \ingroup PdsITGroup
+ */
+int pds_symetric_ber_bsc_model(double rho,unsigned int M, double *BER)
+{
+	double ber;
+	int j;
+
+    if(BER==NULL)   return FALSE;
+
+    if ((M%2)==0)
+    {
+	    ber=0.5*pds_nchoosek(M,M/2)*pow(rho,M/2)*pow(1.0-rho,M/2);
+	    for(j=((M/2)+1);j<=M;j++)
+	    {
+		    ber=ber+pds_nchoosek(M,j)*pow(rho,j)*pow(1.0-rho,M-j);
+	    }
+
+    }
+    else
+    {
+	    ber=0;
+	    for(j=((M+1)/2);j<=M;j++)
+	    {
+		    ber=ber+pds_nchoosek(M,j)*pow(rho,j)*pow(1.0-rho,M-j);
+	    }
+    }
+	*BER=ber;
+
+	return TRUE;
+}
+
+/** \fn int pds_vector_symetric_ber_bsc_model(const PdsVector* RHO,PdsRaNatural M,PdsVector* BER)
+ *  \brief Retorna un vector con las tazas de erro de bit, \f$BER\f$,
+ *  (para cada valor de probabilidad de error dentro del vector RHO) 
+ *  en el problema CEO binario simétrico
+ *  de M fontes \f$ U_m, \forall ~ m \in \{1, 2, ..., M\}\f$, donde \f$\hat{U}_0\f$
+ *  representa la mejor aproximación de \f$U_0\f$ conociendo \f$U_1 U_2 ... U_M\f$. 
+ *
+ *  Estas fuentes son generadas pasando una fuente \f$U_0\f$, con probabilidade
+ *  \f$P(U_0=1)=0.5\f$ , atraves de M canales BSC
+ *  con probabilidades de error \f$P(U_m \neq U0 | U0)=\rho\f$.
+ *
+ *  <center>
+ *  \image html msbscpack.png "Bloque de M fuentes binarias correlacionadas"
+ *  </center>
+ *
+ *
+ *  Quando M es impar :
+ *  \f[ BER= \sum_{j=(M+1)/2}^{M} {{M}\choose{j}} {\rho}^j (1-\rho)^{M-j} \f]
+ *
+ *  Quando M es par :
+ *  \f[ BER= \sum_{j=(M/2)+1}^{M} {{M}\choose{j}} {\rho}^j (1-\rho)^{M-j}+0.5 {{M}\choose{M/2}} {\rho}^{M/2} (1-\rho)^{M/2} \f]
+ *
+ *  <b>!!!!CUIDADO ACTUAL \f$BER=P(U_m\neq U_0 | \lfloor \frac{M+1}{2} \rfloor\leq m \leq M)\f$ !!!!!</b>
+ *
+ *  The formula for calculus of BER is in \cite BER1 and other simplification in \cite BER2 \cite jointsbceo .
+ *
+ *  \param[in] RHO Es un vector con las probabilidades de error \f$\rho\f$ a ser 
+ *  evaluadas. \f$ P(U_m \neq U_0| U_0)=\rho \f$.
+ *  \param[in] M Es el número de canales BSC.
+ *  \param[out] BER Es un vector con la taza de error de bit para cada valor de 
+ *  probabilidades de error \f$\rho\f$ en el vector RHO.
+ *  \return TRUE si todo fue bien, o FALSE sino. 
+ *  \ingroup PdsITGroup
+ */
+int pds_vector_symetric_ber_bsc_model(const PdsVector* RHO,PdsRaNatural M,PdsVector* BER)
+{
+    int dat;
+    PdsRaNatural i;
+    double val;
+
+    if(RHO==NULL)   return FALSE;
+    if(BER==NULL)   return FALSE;
+    if(M<1)         return FALSE;
+
+    if(BER->Nel!=RHO->Nel)   return FALSE;
+
+    for(i=0;i<RHO->Nel;i++)
+    {
+        dat=pds_symetric_ber_bsc_model (RHO->V[i], M,&val);
+        if(dat==FALSE)  return FALSE;
+        BER->V[i]=val;
+    }
+    return TRUE;
+}
+
+
+
 /** \fn int pds_joint_probability_bsc_model(PdsBVector *OmegaM,const PdsVector *Ps,double p0, double *JointProb)
  *  \brief Encuentra la probabilidad conjunta \f$P(\Omega_M)\f$ de tener en la salida 
  *  de un grupo de canales BSC un conjunto de valores binarios formando un vector 
- *  \f$\Omega_M\f$. 
+ *  \f$\Omega_M\f$ \cite jointprobh . 
+ *
+ *  <center>
+ *  \image html mbscpack.png "Bloque de M fuentes binarias correlacionadas"
+ *  </center>
  *
  *  Conocido un conjunto \f$S=\{U_1, U_2, ..., U_M\}\f$ de fuentes binarias,
  *  estas son construidas pasando la fuente binaria
@@ -93,7 +215,11 @@ int pds_joint_probability_bsc_model(PdsBVector *OmegaM,const PdsVector *Ps,doubl
 /** \fn int pds_joint_entropy_bsc_model(const PdsVector *Ps,double p0, double *HJoint)
  *  \brief Encuentra la entropia conjunta \f$ H(U_1,...,U_M)\f$ para M fontes generadas
  *  pasando una fuente U0, con probabilidade Pr(U0=1)=p0, atraves de M canales BSC
- *  con probabilidades de error Ps=[Ps0, Ps1, ..., Ps(M-1)].
+ *  con probabilidades de error Ps=[Ps0, Ps1, ..., Ps(M-1)] \cite jointprobh . 
+ *
+ *  <center>
+ *  \image html mbscpack.png "Bloque de M fuentes binarias correlacionadas"
+ *  </center>
  *
  *  \f[ H(U_1, U_2, ..., U_M)= \sum_{U_1, U_2, ... U_M} P(U_1, U_2, ..., U_M)~log_2(P(U_1, U_2, ..., U_M)) \f]
  *   
@@ -149,8 +275,11 @@ int pds_joint_entropy_bsc_model(const PdsVector *Ps,double p0, double *HJoint)
 
 /** \fn int pds_probability_u0_omega_bsc_model(PdsBVector *OmegaM,const PdsVector *Ps,PdsBaBit U0,double p0, double *PcU0OmegaM, double *PjU0OmegaM)
  *  \brief Encuentra las probabilidades  condicionada \f$P(u_0 |\Omega_M)\f$ y
- *  conjunta \f$P(u_0 \Omega_M)\f$ .
+ *  conjunta \f$P(u_0 \Omega_M)\f$ \cite jointprobh . 
  *
+ *  <center>
+ *  \image html mbscpack.png "Bloque de M fuentes binarias correlacionadas"
+ *  </center>
  *
  *  Conocido un conjunto \f$S=\{U_1, U_2, ..., U_M\}\f$ de fuentes binarias,
  *  estas son construidas pasando la fuente binaria
@@ -165,6 +294,7 @@ int pds_joint_entropy_bsc_model(const PdsVector *Ps,double p0, double *HJoint)
  *  \f[
  *  P(u_0|\Omega_M) =  \frac{P(u_0\Omega_M) }{P(\Omega_M)}
  *  \f]
+ *  Sabiendo que:
  *  \f{eqnarray*}{
  *  P(\Omega_M)& = & P(U_1=u_1|U_0=0) ... P(U_M=u_M|U_0=0) P(U_0=0) \\
  *  ~          & + & P(U_1=u_1|U_0=1) ... P(U_M=u_M|U_0=1) P(U_0=1)
@@ -174,7 +304,7 @@ int pds_joint_entropy_bsc_model(const PdsVector *Ps,double p0, double *HJoint)
  *  \param[in] OmegaM Es un caso de ocurrencia del vector binario.
  *  \param[in] Ps Es el vector de probabilidades de error de las fuentes BSC.
  *  Ps=[Ps0, Ps1, ..., Ps(M-1)]. \f$ {P_s}_{m} \rightarrow Ps(m-1)\f$.
- *  \param[in] u0 Valor de U0 a analiza.
+ *  \param[in] U0 Valor de U0 a analiza.
  *  \param[in] p0 Probabilida Pr(U0=1)=p0 de la fuente U0.
  *  \param[out] PcU0OmegaM Retorna la probabilidad condicionada. \f$P(u_0 |\Omega_M)\f$.
  *  \param[out] PjU0OmegaM Retorna la probabilidad conjuta. \f$P(u_0 \Omega_M)\f$.
@@ -229,7 +359,11 @@ int pds_probability_u0_omega_bsc_model(PdsBVector *OmegaM,const PdsVector *Ps,Pd
 
 
 /** \fn int pds_entropy_u0_omega_bsc_model(const PdsVector *Ps,double p0, double *HCond)
- *  \brief Encuentra la entropia condicionada. \f$ H(U_0|U_1,...,U_M)\f$.
+ *  \brief Encuentra la entropia condicionada. \f$ H(U_0|U_1,...,U_M)\f$ \cite jointprobh . 
+ *
+ *  <center>
+ *  \image html mbscpack.png "Bloque de M fuentes binarias correlacionadas"
+ *  </center>
  *
  *  Dadas M fontes Um , m ={1,2,...,M}, generadas
  *  pasando una fuente U0, con probabilidade Pr(U0=1)=p0, atraves de M canales BSC
@@ -292,9 +426,13 @@ int pds_entropy_u0_omega_bsc_model(const PdsVector *Ps,double p0, double *HCond)
 
 
 /** \fn int pds_symetric_entropy_u0_omega_bsc_model(double rho,PdsBaNatural M, double *HCond)
- *  \brief Encuentra la entropia condicionada. \f$ h(U_0| \rho,M)=H(U_0|U_1,...,U_M)\f$.
+ *  \brief Encuentra la entropia condicionada HCond \cite condsbceo . \f$ HCond=h(U_0| \rho,M)=H(U_0|U_1,...,U_M)\f$.
  *  Este es el caso cuando todas las probabilidades de error son iguales a rho. \f$rho=\rho\f$.
  *
+ *  <center>
+ *  \image html msbscpack.png "Bloque de M fuentes binarias correlacionadas"
+ *  </center>
+ *
  *  Dadas M fontes Um , m ={1,2,...,M}, generadas
  *  pasando una fuente U0, con probabilidade Pr(U0=1)=0.5, atraves de M canales BSC
  *  con probabilidades de error Ps=[rho, rho, ..., rho].
@@ -330,8 +468,14 @@ int pds_symetric_entropy_u0_omega_bsc_model(double rho,PdsBaNatural M, double *H
 
 
 /** \fn int pds_symetric_joint_entropy_bsc_model(double rho,PdsRaNatural M, double *HJoint)
- *  \brief Encuentra la entropia conjunta. \f$ h( \rho,M)=H(U_1,...,U_M)\f$.
- *  Este es el caso cuando todas las probabilidades de error son iguales a rho. \f$rho=\rho\f$.
+ *  \brief Encuentra la entropia conjunta HJoint, \f$ HJoint=h( \rho,M)=H(U_1,...,U_M)\f$, de las señales
+ *  a la salida de un bloque de de M fuentes binarias correlacionadas \cite jointsbceo.
+ * 
+ *  Este es el caso cuando todas las probabilidades de error son iguales a rho \f$=\rho\f$.
+ *
+ *  <center>
+ *  \image html msbscpack.png "Bloque de M fuentes binarias correlacionadas"
+ *  </center>
  *
  *  Dadas M fontes Um , m ={1,2,...,M}, generadas
  *  pasando una fuente U0, con probabilidade Pr(U0=1)=0.5, atraves de M canales BSC
@@ -368,11 +512,16 @@ int pds_symetric_joint_entropy_bsc_model(double rho,PdsRaNatural M, double *HJoi
 
 
 /** \fn int pds_inv_symetric_entropy_u0_omega_bsc_model(double HCond,short int M,double * rho)
- *  \brief Encuentra la inversa de la entropia condicionada. \f$ HCond=h(U_0| \rho,M)=H(U_0|U_1,...,U_M)\f$.
+ *  \brief Encuentra la inversa \f$\rho\f$ de la entropia condicionada HCond \cite condsbceo . 
+ *  \f$ HCond=h(U_0| \rho,M)=H(U_0|U_1,...,U_M)\f$.
+ *
  *  Esta funcion es la inversa de pds_symetric_entropy_u0_omega_bsc_model().
  *  Cuando HCond y M son entregados la funcion retorna el valor de rho.
  *  Este es el caso cuando todas las probabilidades de error son iguales a rho. \f$rho=\rho\f$.
-
+ *
+ *  <center>
+ *  \image html msbscpack.png "Bloque de M fuentes binarias correlacionadas"
+ *  </center>
  *
  *  Dadas M fontes Um , m ={1,2,...,M}, generadas
  *  pasando una fuente U0, con probabilidade Pr(U0=1)=0.5, atraves de M canales BSC
@@ -435,10 +584,16 @@ int pds_inv_symetric_entropy_u0_omega_bsc_model(double HCond,short int M,double
 
 
 /** \fn int pds_inv_symetric_joint_entropy_bsc_model(double HJoint,short int M,double * rho)
- *  \brief Encuentra la inversa de la entropia conjunta. \f$ HJoint=h( \rho,M)=H(U_1,...,U_M)\f$.
+ *  \brief Encuentra la inversa \f$\rho\f$ de la entropia conjunta \f$HJoint\f$
+ *  \cite jointsbceo . \f$ HJoint=h( \rho,M)=H(U_1,...,U_M)\f$
+ *
  *  Esta funcion es la inversa de pds_symetric_joint_entropy_bsc_model().
  *  Cuando HJoint y M son entregados la funcion retorna el valor de rho.
- *  Este es el caso cuando todas las probabilidades de error son iguales a rho. \f$rho=\rho\f$.
+ *  Este es el caso cuando todas las probabilidades de error son iguales a rho \f$=\rho\f$.
+ *
+ *  <center>
+ *  \image html msbscpack.png "Bloque de M fuentes binarias correlacionadas"
+ *  </center>
  *
  *  Dadas M fontes Um , m ={1,2,...,M}, generadas
  *  pasando una fuente U0, con probabilidade Pr(U0=1)=0.5, atraves de M canales BSC
